@@ -430,11 +430,10 @@ class Scraper(CachingSession):
     the only one to be instantiated directly).  It provides a large number
     of options allowing for customization.
 
-    Usage is generally just creating an instance with the desired options and
-    then using the :meth:`urlopen` & :meth:`urlretrieve` methods of that
-    instance.
+    It wraps `requests.Session` and has the same attributes & methods
+    available.
 
-    :param raise_errors: set to True to raise a :class:`HTTPError`
+    :param raise_errors: set to True to raise a `HTTPError`
         on 4xx or 5xx response
     :param requests_per_minute: maximum requests per minute (0 for
         unlimited, defaults to 60)
@@ -442,6 +441,7 @@ class Scraper(CachingSession):
         page returns a (non-404) error
     :param retry_wait_seconds: number of seconds to retry after first failure,
         subsequent retries will double this wait
+    :param verify: set to `False` to disable HTTPS verification.
     """
 
     def __init__(
@@ -531,9 +531,21 @@ class Scraper(CachingSession):
         cert: Union[Text, Tuple[Text, Text], None] = None,
         json: Optional[Any] = None,
         retry_on_404: bool = False,
+        ciphers_list_addition: Union[Text, None] = None,
     ) -> CacheResponse:
         _log.info("{} - {!r}".format(method.upper(), url))
 
+        # allow modification of SSL ciphers list to accommodate misconfigured servers
+        # for example 'HIGH:!DH:!aNULL' to bypass "dh key too small" error
+        # https://stackoverflow.com/questions/38015537/python-requests-exceptions-sslerror-dh-key-too-small
+        if ciphers_list_addition:
+            requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ciphers_list_addition
+            try:
+                requests.packages.urllib3.contrib.pyopenssl.DEFAULT_SSL_CIPHER_LIST += ciphers_list_addition
+            except AttributeError:
+                # no pyopenssl support used / needed / available
+                pass
+
         # apply global timeout
         if not timeout:
             timeout = self.timeout
@@ -616,7 +628,7 @@ class Scraper(CachingSession):
         :returns filename, response: tuple with filename for saved
             response (will be same as given filename if one was given,
             otherwise will be a temp file in the OS temp directory) and
-            a :class:`Response` object that can be used to inspect the
+            a `Response` object that can be used to inspect the
             response headers.
         """
         result = self.request(method, url, data=body, **kwargs)
